-----------------------------------------------------------
--Search and Replace All as follows:
-- 1) Replace <DB> with the name of the database to create.
--    (e.g., Substitute <DB> for DB.)
-- 2) Replace <PATH> with the full path to this file and 
--    others associated with it. Ensure it ends with a 
--    backslash. e.g., C:\MyDatabases\
-----------------------------------------------------------
--
IF NOT EXISTS(SELECT * FROM sys.databases
          WHERE name = N'<DB>')
	CREATE DATABASE <DB>
GO
USE <DB>
--
-- Alter the path so the script can find the CSV files
--
DECLARE
   @data_path nvarchar(256);
SELECT @data_path = '<PATH>';
--
--GO
-- =======================================
-- Delete existing tables
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'VisitMedications'
         )
  DROP TABLE VisitMedications;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'VisitDiagnoses '
         )
  DROP TABLE VisitDiagnoses ;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'VisitProcedures '
         )
  DROP TABLE VisitProcedures ;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Visit'
         )
  DROP TABLE Visit ;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'EmployeeVacation'
         )
  DROP TABLE EmployeeVacation;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Employee'
         )
  DROP TABLE Employee;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Patient'
         )
  DROP TABLE Patient;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'ICD10DiagnosisCodes'
         )
  DROP TABLE ICD10DiagnosisCodes;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'ICD10ProcedureCodes'
         )
  DROP TABLE ICD10ProcedureCodes;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'DrugListings'
         )
  DROP TABLE DrugListings;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'EmployeeCategory'
         )
  DROP TABLE EmployeeCategory;
--
-- Tables from old version in case you want to do your own cross walks
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'ICD9DiagnosisCodes'
         )
  DROP TABLE ICD9DiagnosisCodes;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'ICD9ProcedureCodes'
         )
  DROP TABLE ICD9ProcedureCodes;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'GEMICD9xICD10_CM'
         )
  DROP TABLE GEMICD9xICD10_CM;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'GEMICD9xICD10_PCS'
         )
  DROP TABLE GEMICD9xICD10_PCS;
--
--
-- Create tables
--
CREATE TABLE EmployeeCategory
(
  EmployeeCategory                 nvarchar(50),
     CONSTRAINT pk_EmployeeCategory PRIMARY KEY (EmployeeCategory) 
)

CREATE TABLE DrugListings
(
  SeqNo                            integer,
  LabelCode                        nvarchar(250) NULL,
  Prodcode                         nvarchar(250) NULL,
  Strength                         nvarchar(100) NULL,
  Units                            nvarchar(100) NULL,
  Rx_OTC                           nvarchar(50)  NULL,
  TradeName                        nvarchar(250) NULL,
    CONSTRAINT pk_DrugListings PRIMARY KEY (SeqNo)
)
 
CREATE TABLE ICD10ProcedureCodes
(
  ICD10PCS                         nvarchar(50),
  Description                      nvarchar(500)  NULL ,
  BaseCost                         money NULL,
  PhysicianRole                    real NULL,
  TechnicianRole                   real NULL,
  PhysicianAssistant               nvarchar(4) NULL,
     CONSTRAINT pk_ICD10ProcedureCodes PRIMARY KEY (ICD10PCS) 
)
 
CREATE TABLE ICD10DiagnosisCodes
(
  ICD10CM                          nvarchar(50),
  Description                      nvarchar(500)  NULL ,
     CONSTRAINT pk_ICD10DiagnosisCodes PRIMARY KEY (ICD10CM) 
)
 
CREATE TABLE Patient
(
  PatientID                        integer IDENTITY(1,1) ,
  LastName                         nvarchar(50)  NULL ,
  FirstName                        nvarchar(50)  NULL ,
  DateOfBirth                      datetime  NULL ,
  Gender                           nvarchar(50)  NULL ,
  Telephone                        nvarchar(50)  NULL ,
  Address                          nvarchar(50)  NULL ,
  City                             nvarchar(50)  NULL ,
  State                            nvarchar(50)  NULL ,
  ZIPCode                          nvarchar(50)  NULL ,
  Race                             integer NULL,
  TobaccoUse                       bit NULL,
     CONSTRAINT pk_Patient PRIMARY KEY (PatientID) 
)

CREATE TABLE Employee
(
  EmployeeID                       integer IDENTITY(1,1) ,
  LastName                         nvarchar(50)  NULL ,
  FirstName                        nvarchar(50)  NULL ,
  EmployeeCategory                 nvarchar(50)  NULL ,
  DateHired                        datetime  NULL ,
  DateLeft                         datetime  NULL ,
  EmergencyPhone                   nvarchar(50)  NULL ,
     CONSTRAINT pk_Employee PRIMARY KEY (EmployeeID), 
     CONSTRAINT fk_Employee_EmployeeCategory FOREIGN KEY (EmployeeCategory)
        REFERENCES EmployeeCategory (EmployeeCategory) 
        ON DELETE CASCADE 
        ON UPDATE CASCADE 
)

CREATE TABLE EmployeeVacation
(
  EmployeeID                      integer,
  VacationStart                   datetime,
  VacationEnd                     datetime NULL,
    CONSTRAINT pk_EmployeeVacation PRIMARY KEY (EmployeeID, VacationStart),
    CONSTRAINT fk_EmployeeVac_Employee FOREIGN KEY (EmployeeID)
       REFERENCES Employee (EmployeeID)
       ON DELETE CASCADE
)
 
CREATE TABLE Visit
(
  VisitID                          integer IDENTITY(1,1) ,
  PatientID                        integer  NULL ,
  VisitDate                        datetime  NULL ,
  InsuranceCompany                 nvarchar(50)  NULL ,
  InsuranceGroupCode               nvarchar(50)  NULL ,
  InsuranceMemberCode              nvarchar(50)  NULL ,
  PatientAmountPaid                money  NULL ,
  DateBillSubmitted                datetime  NULL ,
  DateInsurancePaid                datetime  NULL ,
  AmountInsurancePaid              money  NULL ,
  Diastolic                        integer NULL ,
  Systolic                         integer NULL ,
     CONSTRAINT pk_Visit PRIMARY KEY (VisitID), 
     CONSTRAINT fk_Visit_Patient FOREIGN KEY (PatientID)
        REFERENCES Patient (PatientID) 
        ON DELETE CASCADE 
        ON UPDATE CASCADE 
)
 
CREATE TABLE VisitProcedures
(
  VisitProcedureID                 integer IDENTITY(1,1),
  VisitID                          integer,
  ICD10PCS                         nvarchar(50),
  Comment                          nvarchar(500) NULL,
  EmployeeID                       integer  NULL ,
  AmountCharged                    money  NULL ,
  ICD9Procedure                    nvarchar(50) NULL,
     CONSTRAINT pk_VisitProcedure PRIMARY KEY (VisitProcedureID), 
     CONSTRAINT fk_VisitProcedure_Visit FOREIGN KEY (VisitID)
        REFERENCES Visit (VisitID) 
        ON DELETE CASCADE 
        ON UPDATE CASCADE, 
     CONSTRAINT fk_VisitProcedure_ICD10PCS FOREIGN KEY (ICD10PCS)
        REFERENCES ICD10ProcedureCodes (ICD10PCS) 
        ON DELETE CASCADE 
        ON UPDATE CASCADE, 
     CONSTRAINT fk_VisitProcedure_Employee FOREIGN KEY (EmployeeID)
        REFERENCES Employee (EmployeeID) 
        ON DELETE CASCADE 
        ON UPDATE CASCADE 
)
 
CREATE TABLE VisitDiagnoses
(
  VisitID                          integer,
  ICD10CM                          nvarchar(50),
  ICD9Diagnosis                    nvarchar(50) NULL,
  Comments                         nvarchar(500)  NULL ,
     CONSTRAINT pk_VisitDiagnoses PRIMARY KEY (VisitID, ICD10CM), 
     CONSTRAINT fk_VisitDiagnoses_ICD10CM FOREIGN KEY (ICD10CM)
        REFERENCES ICD10DiagnosisCodes (ICD10CM) 
        ON DELETE CASCADE 
        ON UPDATE CASCADE, 
     CONSTRAINT fk_VisitDiagnoses_Visit FOREIGN KEY (VisitID)
        REFERENCES Visit (VisitID) 
        ON DELETE CASCADE 
        ON UPDATE CASCADE 
)

CREATE TABLE VisitMedications
(
  VisitID                                    integer,
  DrugSeqNo                                  integer,
  DrugCode                                   nvarchar(50) NULL,
  Comments                                   nvarchar(255) NULL,
    CONSTRAINT pk_VisitMedications PRIMARY KEY (VisitID, DrugSeqNo),
    CONSTRAINT fk_VisitMeds_Visit FOREIGN KEY (VisitID)
       REFERENCES Visit (VisitID)
       ON DELETE CASCADE
)
CREATE TABLE ICD9DiagnosisCodes
(
  ICD9DiagnosisCode nvarchar(50) NOT NULL,
  ShortDescription nvarchar(255) NULL,
    CONSTRAINT pk_ICD9DiagnosisCodes PRIMARY KEY (ICD9DiagnosisCode)
)

CREATE TABLE ICD9ProcedureCodes
(
  ICD9ProcedureCode nvarchar(50) NOT NULL,
  ShortDescription nvarchar(255) NULL,
  StartDate datetime NULL,
  BaseCost money NULL,
  PhysicianRole float NULL,
  TechnicianRole float NULL,
  PhysicianAssistant nvarchar(10) NULL,
    CONSTRAINT pk_ICD9ProcedureCodes PRIMARY KEY (ICD9ProcedureCode)
)

CREATE TABLE GEMICD9xICD10_CM
(
  ICD9CMS nvarchar(50) NOT NULL,
  ICD10CM nvarchar(50) NOT NULL,
  MatchCode integer NULL
)

CREATE TABLE GEMICD9xICD10_PCS
(
  ICD9PCS nvarchar(50) NOT NULL,
  ICD10PCS nvarchar(50) NOT NULL,
  MatchCode integer NULL
)


--
-- Load table data
--
-- Table 1 EmployeeCategory
--
EXECUTE (N'BULK INSERT EmployeeCategory FROM ''' + @data_path + N'EmployeeCategory.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 2 DrugListings
--
EXECUTE (N'BULK INSERT DrugListings FROM ''' + @data_path + N'DrugListings.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 3 ICD10ProcedureCodes
--
EXECUTE (N'BULK INSERT ICD10ProcedureCodes FROM ''' + @data_path + N'ICD10ProcedureCodes.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 4 ICD10DiagnosisCodes
--
EXECUTE (N'BULK INSERT ICD10DiagnosisCodes FROM ''' + @data_path + N'ICD10DiagnosisCodes.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 5 Patient
--
EXECUTE (N'BULK INSERT Patient FROM ''' + @data_path + N'Patient.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 6 Employee
--
EXECUTE (N'BULK INSERT Employee FROM ''' + @data_path + N'Employee.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 7 EmployeeVacation
--
EXECUTE (N'BULK INSERT EmployeeVacation FROM ''' + @data_path + N'EmployeeVacation.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 8 Visit
--
EXECUTE (N'BULK INSERT Visit FROM ''' + @data_path + N'Visit.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 9 VisitProcedures
--
EXECUTE (N'BULK INSERT VisitProcedures FROM ''' + @data_path + N'VisitProcedures.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 10 VisitDiagnoses
--
EXECUTE (N'BULK INSERT VisitDiagnoses FROM ''' + @data_path + N'VisitDiagnoses.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 11 VisitMedications
--
EXECUTE (N'BULK INSERT VisitMedications FROM ''' + @data_path + N'VisitMedications.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');

--
-- Table 12 ICD9DiagnosisCodes
--
EXECUTE (N'BULK INSERT ICD9DiagnosisCodes FROM ''' + @data_path + N'ICD9DiagnosisCodes.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 13 ICD9ProcedureCodes
--
EXECUTE (N'BULK INSERT ICD9ProcedureCodes FROM ''' + @data_path + N'ICD9ProcedureCodes.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 14 GEMICD9xICD10_CM
--
EXECUTE (N'BULK INSERT GEMICD9xICD10_CM FROM ''' + @data_path + N'GEMICD9xICD10_CM.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 15 GEMICD9xICD10_PCS
--
EXECUTE (N'BULK INSERT GEMICD9xICD10_PCS FROM ''' + @data_path + N'GEMICD9xICD10_PCS.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= ''\t'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');

-- ================================================
-- List table names and row counts for confirmation
--
GO
SET NOCOUNT ON
SELECT 'EmployeeCategory' "Table", COUNT(*) "Rows" FROM EmployeeCategory     UNION
SELECT 'DrugListings',             COUNT(*)  FROM DrugListings               UNION
SELECT 'ICD10ProcedureCodes',      COUNT(*)  FROM ICD10ProcedureCodes        UNION
SELECT 'ICD10DiagnosisCodes',      COUNT(*)  FROM ICD10DiagnosisCodes        UNION
SELECT 'Patient',                  COUNT(*)  FROM Patient                    UNION
SELECT 'Employee',                 COUNT(*)  FROM Employee                   UNION
SELECT 'EmployeeVacation',         COUNT(*)  FROM EmployeeVacation           UNION
SELECT 'Visit',                    COUNT(*)  FROM Visit                      UNION
SELECT 'VisitProcedures',          COUNT(*)  FROM VisitProcedures            UNION
SELECT 'VisitDiagnoses',           COUNT(*)  FROM VisitDiagnoses             UNION
SELECT 'VisitMedications',         COUNT(*)  FROM VisitMedications
ORDER BY 1;
SET NOCOUNT OFF
GO
